@@ -56,7 +56,7 @@ main (int argc, char *argv[])
         return 2;
     }
 
-    setlocale(LC_ALL, "");
+    setlocale(LC_ALL, "en_US.UTF-8");
     init_idn (&ctx);
 
     file = argv[3];
